==> slick-0.0.26.tar.gz: lib/controls/form_input/slick_number_input.dart <==
import 'package:slick/configuration/slick_configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

class SlickNumberInput extends StatelessWidget {
  SlickNumberInput({
    Key key,
    @required this.initialValue,
    @required this.labelText,
    @required this.onChanged,
    this.validator,
  }) : super(key: key);

  final String initialValue;
  final String labelText;
  final ValueChanged<String> onChanged;
  final FormFieldValidator<String> validator;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: const EdgeInsets.only(top: 8.0, left: 16),
      child: TextFormField(
        initialValue: initialValue,
        onChanged: onChanged,
        keyboardType: TextInputType.number,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText.toUpperCase(),
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText.toUpperCase(),
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: <TextInputFormatter>[
          FilteringTextInputFormatter.allow(RegExp(r'^[0-9,]*$'))
        ], // Only numbers can be entered
        validator: validator,
      ),
    );
  }
}

==> slick-0.0.36.tar.gz: lib/controls/form_input/slick_number_input.dart <==
import 'package:slick/configuration/slick_configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

class SlickNumberInput<T> extends StatelessWidget {
  SlickNumberInput({
    Key key,
    this.initialValue,
    this.labelText,
    @required this.onChanged,
    this.validator,
    this.padding = const EdgeInsets.only(top: 8.0, left: 16),
  }) : super(key: key);

  final T initialValue;
  final String labelText;
  final ValueChanged<T> onChanged;
  final FormFieldValidator<String> validator;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: padding,
      child: TextFormField(
        initialValue: initialValue.toString(),
        onChanged: processOnChanged,
        keyboardType: TextInputType.number,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText != null ? labelText.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: <TextInputFormatter>[
          FilteringTextInputFormatter.allow(RegExp(r'^[0-9,]*$'))
        ], // Only numbers can be entered
        validator: validator,
      ),
    );
  }

  void processOnChanged(String val) {
    T result;
    if (T is int) {
      int v = int.tryParse(val);
      if (v == null) v = 0;
      result = v as T;
    }

    if (T is double) {
      double v = double.tryParse(val);
      if (v == null) v = 0;
      result = v as T;
    }

    onChanged(result);
  }
}
